==> haskell-options-1.2.1.2-36.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-options.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 z-options-z-options-internal
version:              1.2.1.2
package-name:         options
lib-name:             options-internal
id:                   options-1.2.1.2-6J2Rxna3aIEuHe44tLQI5-options-internal
key:                  options-1.2.1.2-6J2Rxna3aIEuHe44tLQI5-options-internal
license:              MIT
maintainer:           Chris Martin <chris@typeclasses.com>
author:               John Millikin <john@john-millikin.com>
stability:            stable
homepage:             https://github.com/typeclasses/options/
synopsis:             Powerful and easy command-line option parser
description:
    Lets library and application developers easily work with command-line options.

category:             Console
abi:                  08a875ceb866221e5976d1522cebd586
exposed-modules:
    Options.Help Options.Tokenize Options.Types Options.Util

import-dirs:          /usr/lib/ghc-9.6.6/site-local/options-1.2.1.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/options-1.2.1.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/options-1.2.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-options
hs-libraries:         HSoptions-1.2.1.2-6J2Rxna3aIEuHe44tLQI5-options-internal
depends:
    base-4.18.2.1 containers-0.6.7
    monads-tf-0.3.0.1-Iu8LT2HmoyzIomyBGSfa1u

haddock-interfaces:   /usr/share/doc/haskell-options/html/options.haddock
haddock-html:         /usr/share/doc/haskell-options/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 options
version:              1.2.1.2
visibility:           public
id:                   options-1.2.1.2-J3to70TLD2KHxKq1xPVSdI
key:                  options-1.2.1.2-J3to70TLD2KHxKq1xPVSdI
license:              MIT
maintainer:           Chris Martin <chris@typeclasses.com>
author:               John Millikin <john@john-millikin.com>
stability:            stable
homepage:             https://github.com/typeclasses/options/
synopsis:             Powerful and easy command-line option parser
description:
    Lets library and application developers easily work with command-line options.

category:             Console
abi:                  4b2d575dff918f68d44f3616a753949a
exposed:              True
exposed-modules:      Options
import-dirs:          /usr/lib/ghc-9.6.6/site-local/options-1.2.1.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/options-1.2.1.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/options-1.2.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-options
hs-libraries:         HSoptions-1.2.1.2-J3to70TLD2KHxKq1xPVSdI
depends:
    base-4.18.2.1 containers-0.6.7
    monads-tf-0.3.0.1-Iu8LT2HmoyzIomyBGSfa1u
    options-1.2.1.2-6J2Rxna3aIEuHe44tLQI5-options-internal

haddock-interfaces:   /usr/share/doc/haskell-options/html/options.haddock
haddock-html:         /usr/share/doc/haskell-options/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-options-1.2.1.2-37-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-options.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 z-options-z-options-internal
version:              1.2.1.2
package-name:         options
lib-name:             options-internal
id:                   options-1.2.1.2-8HKIYoxv5UMCVjQZK8SzTC-options-internal
key:                  options-1.2.1.2-8HKIYoxv5UMCVjQZK8SzTC-options-internal
license:              MIT
maintainer:           Chris Martin <chris@typeclasses.com>
author:               John Millikin <john@john-millikin.com>
stability:            stable
homepage:             https://github.com/typeclasses/options/
synopsis:             Powerful and easy command-line option parser
description:
    Lets library and application developers easily work with command-line options.

category:             Console
abi:                  a0d9a173bf03586f77ab4aa20d01ef6c
exposed-modules:
    Options.Help Options.Tokenize Options.Types Options.Util

import-dirs:          /usr/lib/ghc-9.6.6/site-local/options-1.2.1.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/options-1.2.1.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/options-1.2.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-options
hs-libraries:         HSoptions-1.2.1.2-8HKIYoxv5UMCVjQZK8SzTC-options-internal
depends:
    base-4.18.2.1 containers-0.6.7
    monads-tf-0.3.0.1-Iu8LT2HmoyzIomyBGSfa1u

haddock-interfaces:   /usr/share/doc/haskell-options/html/options.haddock
haddock-html:         /usr/share/doc/haskell-options/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 options
version:              1.2.1.2
visibility:           public
id:                   options-1.2.1.2-Ll8emrwh5ZZ69kZWAqaJpB
key:                  options-1.2.1.2-Ll8emrwh5ZZ69kZWAqaJpB
license:              MIT
maintainer:           Chris Martin <chris@typeclasses.com>
author:               John Millikin <john@john-millikin.com>
stability:            stable
homepage:             https://github.com/typeclasses/options/
synopsis:             Powerful and easy command-line option parser
description:
    Lets library and application developers easily work with command-line options.

category:             Console
abi:                  1ca7119e7f905f0c82360c4ad60a262d
exposed:              True
exposed-modules:      Options
import-dirs:          /usr/lib/ghc-9.6.6/site-local/options-1.2.1.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/options-1.2.1.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/options-1.2.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-options
hs-libraries:         HSoptions-1.2.1.2-Ll8emrwh5ZZ69kZWAqaJpB
depends:
    base-4.18.2.1 containers-0.6.7
    monads-tf-0.3.0.1-Iu8LT2HmoyzIomyBGSfa1u
    options-1.2.1.2-8HKIYoxv5UMCVjQZK8SzTC-options-internal

haddock-interfaces:   /usr/share/doc/haskell-options/html/options.haddock
haddock-html:         /usr/share/doc/haskell-options/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
